/*
	Realisation of commands for work with encoders
	EG, ER
		by Mad
*/

#include <avr/io.h>
#include <stdlib.h>
#include "eterm.h"
#include "encoders.h"

// ---------------------------------------------------------------------------------

void proceed_e_command(char cmd, bool correct)
{
	if(!correct) {
		printf("E syntax error\n");
		return;
	}

	switch(cmd) {
		case 'G': {
			printf("E=%li,%li\n", EncoderCounter(1), EncoderCounter(2));
		} break;

		case 'R': {
			EncoderClear(1);
			EncoderClear(2);
			printf("E=0,0\n");
		} break;

		default:
			printf("E-error\n");
	}
}
// ---------------------------------------------------------------------------------

static bool e_parser(char c, bool reinit) {

	static char	e_cmd;
	static bool wait_eol;
	static bool cmd_correct;

	if(reinit) {
		// clear
		e_cmd = 0;
		wait_eol = false;
		cmd_correct = false;
		return false;
	}

	if(wait_eol) {
		if(c == ' ')
			return false;
		if(c == '\n') {
			proceed_e_command(e_cmd, cmd_correct);
			e_cmd = 0;
			wait_eol = cmd_correct = false;
			return true;
		}
		cmd_correct = false;
		return false;
	}
	else {
		switch(c) {
			case 'G':
			case 'g':
				e_cmd = 'G';
				wait_eol = cmd_correct = true;
				return false;
			case 'R':
			case 'r':
				e_cmd = 'R';
				wait_eol = cmd_correct = true;
				return false;
			default:
				wait_eol = true;
				return false;
		}
	}
}
// ---------------------------------------------------------------------------------


// ---------------------------------------------------------------------------------
// ---------------------------------------------------------------------------------

// -- table --

static parser_t ecommand[] = {
		PARSER_INIT('E', "Encoders control", e_parser)
};

void register_ecommand(void) {
		register_parser(ecommand);
}
// ---------------------------------------------------------------------------------
